Teknoisme | Paham Teknologi
Description: Paham Teknologi

## 4 Aplikasi Terbaik untuk Membaca E-book di Smartphone

Seiring perkembangan zaman, manusia semakin cerdas memanfaatkan teknologi yang semakin berkembang pesat. Salah satunya ialah e-book. E-book merupakan reinkarnasi dari buku. Tentu saja di zaman serba digital ini banyak orang yang lebih memilih e-book daripada buku. Alasannya karena e-book lebih praktis dan murah jika dibandingkan buku.

## Nexus 5X dan 6P Telah Resmi Dirilis

Beberapa hari yang lalu Google telah mengumumkan secara resmi mengenai sistem operasi terbarunya, yaitu Android 6.0 atau Android Marshmallow. Pada hari ini, Rabu (30/09/2015) dini hari waktu WIB, atau Selasa siang waktu San Fransisco, Amerika Serikat, Google telah resmi meluncurkan dua smartphone terbarunya, yaitu Nexus

## Android Marshmallow Akan Segera Dirilis!

Pada beberapa waktu yang lalu telah diumumkan bahwa sistem operasi Android terbaru milik Google diberi nama Marshmallow. Sebelumnya memang masih samar-samar dan hanya diberi nama dengan inisial ‘M’ saja. Nama ini pun akhirnya terkuak dari munculnya patung Android sedang menggenggam marshmallow di depan kantor Android

## Alasan Mengapa BlackBerry Akhirnya Pakai Android

Beberapa waktu yang lalu memang sudah dikabarkan bahwa BlackBerry akan siap me-launching smartphone yang berbasis sitem operasi Android. CEO BlackBerry, John Chen, telah membenarkan hal tersebut. Sebenarnya apa alasan yang membuat perusahaan asal Kanada ini mau mengadopsi sistem operasi buatan Google tersebut? Pertanyaan ini banyak

## 5 Cara Menghemat Kuota Data Internet di Smartphone

Saat ini penggunaan smartphone semakin berkembang seiring dengan perkembangan zaman. Jika dahulu ponsel hanya digunakan untuk berkomunikasi melalui telepon atau SMS saja, kini ponsel sudah dapat digunakan untuk browsing, bergaul di media sosial, menonton video, mendengarkan musik, hingga bermain game. Kinis setiap orang dituntut untuk

## Pertimbangkan Hal-hal Ini Sebelum Membeli Mouse Gaming

Siapa sekarang yang tidak menyukai game? Hampir setiap orang menyukai game. Game memang bisa memberikan efek relaksasi dari padatnya aktivitas sehari-hari. Tidak sedikit juga orang yang kecanduan game. Para gamers – istilah untuk pecinta game, biasanya membutuhkan peralatan main yang cukup handal untuk mendukung permainannya.

## 5 Aplikasi Wajib untuk Para Pecinta Selfie

Istilah ‘selfie’ dalam kurun waktu belakangan ini menjadi cukup eksis. Hampir seluruh orang di dunia menyukai kegiatan ini. Kata selfie merupakan singkatan dari self potrait, artinya foto yang diambil oleh diri sendiri. Biasanya selfie dilakukan dengan menggunakan kamera ponsel atau digital, terkadang juga menggunakan bantuan

## Ini Perbedaan JPEG, PNG, dan GIF yang Harus Diketahui!

Anda pasti sudah tidak asing lagi mendengar istilah JPEG, PNG, maupun GIF. Terutama bagi pecinta fotografi maupun desain grafis, ketiga istilah ini pasti sangat akrab di telinga. Ketiganya merupakan format yang digunakan dalam menyimpan foto atau gambar. Namun banyak orang yang tidak memperhatikan bahwa tiap

## Ini Tips Agar Charge Smartphone Bisa Dua Kali Lebih Cepat

Di era yang serba canggih seperti saat ini, segala aktivitas manusia setiap harinya banyak dibantu oleh smartphone. Mulai dari mengirimkan email, membuka media sosial, mendengarkan musik, browsing, menonton video, hingga menyelesaikan tugas kantor. Tidak bisa dipungkiri bahwa kini smartphone telah menjadi kebutuhan yang cukup penting untuk

## Google Chrome vs Microsoft Edge, Hebat Mana?

Hingga saat ini, Google Chrome dikatakan sebagai salah satu browser yang mempunyai performa tinggi. Penggunanya pun cukup banyak jika dibandingkan dengan browser lainnya. Produk keluaran Google ini memang dapat disimpulkan sebagai browser terbaik untuk saat ini. Namun setelah kemunculan Microsoft Windows 10 pada Juli 2015